@@ -1,21 +1,27 @@
 /**
  * Self-Organizing Maps on a cluster
- *  Copyright (C) 2013 Peter Wittek
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- */
+ * MIT License
+ * 
+ * Copyright (c) 2013 Peter Wittek
+ * 
+ * Permission is hereby granted, free of charge, to any person obtaining a copy
+ * of this software and associated documentation files (the "Software"), to deal
+ * in the Software without restriction, including without limitation the rights
+ * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+ * copies of the Software, and to permit persons to whom the Software is
+ * furnished to do so, subject to the following conditions:
+ * 
+ * The above copyright notice and this permission notice shall be included in all
+ * copies or substantial portions of the Software.
+ * 
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+ * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+ * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+ * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+ * SOFTWARE.
+**/
 
 
 #include <cmath>
@@ -27,7 +33,7 @@
 
 #include "somoclu.h"
 #ifndef HAVE_R
-using namespace std;
+using std::string;
 #endif
 // From https://stackoverflow.com/questions/17432502/how-can-i-measure-cpu-time-and-wall-clock-time-on-both-linux-windows
 //  Windows
@@ -66,6 +72,10 @@ using Rcpp::Rcerr;
 #else
 #include <iostream>
 #include <iomanip>
+using std::cout;
+using std::cerr;
+using std::endl;
+using std::flush;
 #endif  // HAVE_R
 
 void cuda_abort(string err) {
@@ -182,7 +192,7 @@ void train(int itask, float *data, svm_node **sparseData,
     /// Parameters for SOM
     ///
     if (radius0 == 0) {
-        unsigned int minDim = min(map.nSomX, map.nSomY);
+        unsigned int minDim = std::min(map.nSomX, map.nSomY);
         radius0 = minDim / 2.0f;              /// init radius for updating neighbors
     }
     if (radiusN == 0) {
